@@ -21,18 +21,24 @@ private Q_SLOTS:
 
     void initTestCase();
 
+    void optionCase_data();
+    void optionCase();
+
     void stringMatch_data();
     void stringMatch();
 
     void phraseMatch_data();
     void phraseMatch();
 
+    void regexMatch_data();
+    void regexMatch();
+
+    void wordListMatch_data();
+    void wordListMatch();
+
     void filenameContent_data();
     void filenameContent();
 
-    void optionCase_data();
-    void optionCase();
-
     void folderTree_data();
     void folderTree();
 
@@ -195,6 +201,30 @@ void FilenameSearchTest::cleanupTestCase()
     }
 };
 
+//  TODO: the optionCase test relies on filenameContent, ought to have an option/query that does not depend on test files.
+
+void FilenameSearchTest::optionCase_data()
+{
+    addColumns();
+
+    addRow("No Match", QByteArrayLiteral("checkContent=no"), QByteArrayLiteral("curiouser"), {});
+    addRow("Lower Case", QByteArrayLiteral("checkContent=yes"), QByteArrayLiteral("curiouser"), {QByteArrayLiteral("alice2.txt")});
+    addRow("Mixed Case", QByteArrayLiteral("checkContent=Yes"), QByteArrayLiteral("curiouser"), {QByteArrayLiteral("alice2.txt")});
+    addRow("Upper Case", QByteArrayLiteral("checkContent=YES"), QByteArrayLiteral("curiouser"), {QByteArrayLiteral("alice2.txt")});
+}
+
+void FilenameSearchTest::optionCase()
+{
+    QFETCH(QByteArray, searchOptions);
+    QFETCH(QByteArray, searchString);
+    QFETCH(QByteArrayList, expectedFiles);
+
+    const QString path = QFINDTESTDATA("data/filename-content");
+    QByteArrayList results = doSearchQuery(buildSearchQuery(searchString, searchOptions, path), {});
+
+    QCOMPARE(results, expectedFiles);
+}
+
 void FilenameSearchTest::stringMatch_data()
 {
     addColumns();
@@ -205,13 +235,13 @@ void FilenameSearchTest::stringMatch_data()
     addRow("Filename Extension Match",
            QByteArray(""),
            QByteArrayLiteral(".txt"),
-           {QByteArrayLiteral("Rabbit.TXT"), QByteArrayLiteral("alice.txt"), QByteArrayLiteral("rabbit.txt")});
+           {QByteArrayLiteral("Rabbit.TXT"), QByteArrayLiteral("alice.txt"), QByteArrayLiteral("rabbit.txt"), QByteArrayLiteral("walrus.txt")});
     addRow("Filename Leading Substring Match", QByteArray(""), QByteArrayLiteral("alic"), {QByteArrayLiteral("alice.txt")});
     addRow("Filename Trailing Substring Match", QByteArray(""), QByteArrayLiteral("lice.txt"), {QByteArrayLiteral("alice.txt")});
     addRow("Filename Substring Match", QByteArray(""), QByteArrayLiteral("lic"), {QByteArrayLiteral("alice.txt")});
     addRow("Filename Case Insensitive Match", QByteArray(""), QByteArrayLiteral("rabbit"), {QByteArrayLiteral("Rabbit.TXT"), QByteArrayLiteral("rabbit.txt")});
 
-    addRow("No Content Match", QByteArray(""), QByteArrayLiteral("Cheshire"), {});
+    addRow("No Content Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Cheshire"), {});
     addRow("Content Word Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Wonderland"), {QByteArrayLiteral("alice.txt")});
     addRow("Content Leading Substring Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Wonder"), {QByteArrayLiteral("alice.txt")});
     addRow("Content Trailing Substring Match", QByteArray("checkContent=yes"), QByteArrayLiteral("land"), {QByteArrayLiteral("alice.txt")});
@@ -222,6 +252,7 @@ void FilenameSearchTest::stringMatch_data()
            {QByteArrayLiteral("Rabbit.TXT"), QByteArrayLiteral("rabbit.txt")});
 
     addRow("Content Word Apostrophe Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Alice's"), {QByteArrayLiteral("alice.txt")});
+    addRow("Content Word Escaped Apostrophe Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Alice\'s"), {QByteArrayLiteral("alice.txt")});
 }
 
 void FilenameSearchTest::stringMatch()
@@ -240,13 +271,21 @@ void FilenameSearchTest::phraseMatch_data()
 {
     addColumns();
 
-    addRow("No Content Phrase Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Cheshire Cat"), {});
-    addRow("Content Exact Phrase Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Adventures in Wonderland"), {QByteArrayLiteral("alice.txt")});
+    addRow("No Content Phrase Match", QByteArray("syntax=phrase&checkContent=yes"), QByteArrayLiteral("Cheshire Cat"), {});
+    addRow("Content Exact Phrase Match",
+           QByteArray("syntax=phrase&checkContent=yes"),
+           QByteArrayLiteral("Adventures in Wonderland"),
+           {QByteArrayLiteral("alice.txt")});
 
-    //  Check searches for collections of words work rather than exact phrases.
+    //  Check explicit phrase syntax searches
 
-    addRow("Content Soup Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Adventures Wonderland"), {QByteArrayLiteral("alice.txt")});
-    addRow("Content Random Soup Match", QByteArray("checkContent=yes"), QByteArrayLiteral("Wonderland Adventures"), {QByteArrayLiteral("alice.txt")});
+    addRow("Filename Phrase Query with Phrase Match", QByteArray("syntax=phrase"), QByteArrayLiteral("alice"), {QByteArrayLiteral("alice.txt")});
+    addRow("Filename Phrase Query with Regex Match", QByteArray("syntax=phrase"), QByteArrayLiteral("al.*ce"), {});
+    addRow("Content Phrase Query with Phrase Match",
+           QByteArray("syntax=phrase&checkContent=yes"),
+           QByteArrayLiteral("Adventures in Wonderland"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("No Content Phrase Query with Regex Match", QByteArray("syntax=phrase&checkContent=yes"), QByteArrayLiteral("Advent.* in Wond.*"), {});
 }
 
 void FilenameSearchTest::phraseMatch()
@@ -256,10 +295,120 @@ void FilenameSearchTest::phraseMatch()
     QFETCH(QByteArrayList, expectedFiles);
 
     const QString path = QFINDTESTDATA("data/stringMatch");
+    QByteArrayList results = doSearchQuery(buildSearchQuery(searchString, searchOptions, path), {});
 
-    QEXPECT_FAIL("Content Soup Match", "Should match a collection of terms", Continue);
-    QEXPECT_FAIL("Content Random Soup Match", "Should match a disordered collection of terms", Continue);
+    QCOMPARE(results, expectedFiles);
+}
 
+void FilenameSearchTest::regexMatch_data()
+{
+    addColumns();
+
+    addRow("Filename Regex Query with Regex Match", QByteArray("syntax=regex"), QByteArrayLiteral("al.*ce"), {QByteArrayLiteral("alice.txt")});
+    addRow("Content Regex Query with Regex Match",
+           QByteArray("syntax=regex&checkContent=yes"),
+           QByteArrayLiteral("Advent.* in Wond.*"),
+           {QByteArrayLiteral("alice.txt")});
+
+    addRow("Content Start of String Match",
+           QByteArrayLiteral("syntax=regex&checkContent=yes"),
+           QByteArrayLiteral("^Walrus"),
+           {QByteArrayLiteral("walrus.txt")});
+    addRow("No Content Start of String Match", QByteArrayLiteral("syntax=regex&checkContent=yes"), QByteArrayLiteral("^Carpenter"), {});
+    addRow("Content End of String Match",
+           QByteArrayLiteral("syntax=regex&checkContent=yes"),
+           QByteArrayLiteral("Carpenter$"),
+           {QByteArrayLiteral("walrus.txt")});
+    addRow("No Content End of String Match", QByteArrayLiteral("syntax=regex&checkContent=yes"), QByteArrayLiteral("Walrus$"), {});
+
+    addRow("Content Word Escaped Backslash Match",
+           QByteArray("syntax=regex&checkContent=yes"),
+           QByteArrayLiteral("Alice\\'s"),
+           {QByteArrayLiteral("alice.txt")});
+
+    addRow("Content Invalid Regular Expression", QByteArrayLiteral("syntax=regex&checkContent=yes"), QByteArrayLiteral("+"), {});
+    addRow("Content Escaped Regex Special Character",
+           QByteArrayLiteral("syntax=regex&checkContent=yes"),
+           QByteArrayLiteral("\\+"),
+           {QByteArrayLiteral("walrus.txt")});
+    addRow("No Content Escaped Regex Special Character", QByteArrayLiteral("syntax=regex&checkContent=yes"), QByteArrayLiteral("\\*"), {});
+}
+
+void FilenameSearchTest::regexMatch()
+{
+    QFETCH(QByteArray, searchOptions);
+    QFETCH(QByteArray, searchString);
+    QFETCH(QByteArrayList, expectedFiles);
+
+    const QString path = QFINDTESTDATA("data/stringMatch");
+    QByteArrayList results = doSearchQuery(buildSearchQuery(searchString, searchOptions, path), {});
+
+    QCOMPARE(results, expectedFiles);
+}
+
+void FilenameSearchTest::wordListMatch_data()
+{
+    addColumns();
+
+    //  Check searches for collections of words work rather than exact phrases.
+
+    addRow("Content Soup Match", QByteArray("syntax=wordList&checkContent=yes"), QByteArrayLiteral("Adventures Wonderland"), {QByteArrayLiteral("alice.txt")});
+    addRow("Content Random Soup Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("Wonderland Adventures"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Quoted Phrase Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("'Adventures in Wonderland'"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Underscore Separated Phrase Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("Adventures_in_Wonderland"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Quoted Multiline Phrase Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("'Wonderland Lewis'"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("No Content Single Quoted Phrase Match", QByteArray("syntax=wordList&checkContent=yes"), QByteArrayLiteral("'Wonderland Adventures'"), {});
+    addRow("No Content Double Quoted Phrase Match", QByteArray("syntax=wordList&checkContent=yes"), QByteArrayLiteral("\"Wonderland Adventures\""), {});
+    addRow("No Content Underscore Separated Phrase Match", QByteArray("syntax=wordList&checkContent=yes"), QByteArrayLiteral("Wonderland_Adventures"), {});
+    addRow("Content Quoted Phrases Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("\"Adventures in Wonderland\" 'Lewis Carroll'"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Single Quoted Apostrophe Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("'Alice's Adventures'"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Double Quoted Apostrophe Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("\"Alice's Adventures\""),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Underscore Separated Apostrophe Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("Alice's_Adventures"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Single Quoted Escaped Apostrophe Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("'Alice\\'s Adventures'"),
+           {QByteArrayLiteral("alice.txt")});
+    addRow("Content Double Quoted Escaped Apostrophe Match",
+           QByteArray("syntax=wordList&checkContent=yes"),
+           QByteArrayLiteral("\"Alice\\'s Adventures\""),
+           {QByteArrayLiteral("alice.txt")});
+
+    addRow("Content Regex Special Character", QByteArrayLiteral("syntax=wordList&checkContent=yes"), QByteArrayLiteral("+"), {QByteArrayLiteral("walrus.txt")});
+    addRow("No Content Escaped Regex Special Character", QByteArrayLiteral("syntax=wordList&checkContent=yes"), QByteArrayLiteral("\\*"), {});
+    addRow("No Content Quoted Regex Special Character", QByteArrayLiteral("syntax=wordList&checkContent=yes"), QByteArrayLiteral("'*'"), {});
+}
+
+void FilenameSearchTest::wordListMatch()
+{
+    QFETCH(QByteArray, searchOptions);
+    QFETCH(QByteArray, searchString);
+    QFETCH(QByteArrayList, expectedFiles);
+
+    const QString path = QFINDTESTDATA("data/stringMatch");
     QByteArrayList results = doSearchQuery(buildSearchQuery(searchString, searchOptions, path), {});
 
     QCOMPARE(results, expectedFiles);
@@ -291,30 +440,6 @@ void FilenameSearchTest::filenameContent()
     QCOMPARE(results, expectedFiles);
 }
 
-//  TODO: the optionCase test relies on filenameContent, ought to have an option/query that does not depend on test files.
-
-void FilenameSearchTest::optionCase_data()
-{
-    addColumns();
-
-    addRow("No Match", QByteArrayLiteral("checkContent=no"), QByteArrayLiteral("curiouser"), {});
-    addRow("Lower Case", QByteArrayLiteral("checkContent=yes"), QByteArrayLiteral("curiouser"), {QByteArrayLiteral("alice2.txt")});
-    addRow("Mixed Case", QByteArrayLiteral("checkContent=Yes"), QByteArrayLiteral("curiouser"), {QByteArrayLiteral("alice2.txt")});
-    addRow("Upper Case", QByteArrayLiteral("checkContent=YES"), QByteArrayLiteral("curiouser"), {QByteArrayLiteral("alice2.txt")});
-}
-
-void FilenameSearchTest::optionCase()
-{
-    QFETCH(QByteArray, searchOptions);
-    QFETCH(QByteArray, searchString);
-    QFETCH(QByteArrayList, expectedFiles);
-
-    const QString path = QFINDTESTDATA("data/filename-content");
-    QByteArrayList results = doSearchQuery(buildSearchQuery(searchString, searchOptions, path), {});
-
-    QCOMPARE(results, expectedFiles);
-}
-
 //  Search including hidden files, to catch the .bak (that may be considered hidden)
 
 void FilenameSearchTest::folderTree_data()
