@@ -9,10 +9,10 @@
 #define KPROXYDLG_H
 
 #include "ui_kproxydlg.h"
-#include <KCModule>
-#include <KSharedConfig>
 
-#include "../ksaveioconfig.h"
+#include <KCModule>
+
+#include "kioslave.h"
 
 class KProxyDialog : public KCModule
 {
@@ -28,6 +28,22 @@ public:
     };
     Q_DECLARE_FLAGS(DisplayUrlFlags, DisplayUrlFlag)
 
+    /*
+     * Types of proxy configuration
+     * @li NoProxy     - No proxy is used
+     * @li ManualProxy - Proxies are manually configured
+     * @li PACProxy    - A Proxy configuration URL has been given
+     * @li WPADProxy   - A proxy should be automatically discovered
+     * @li EnvVarProxy - Use the proxy values set through environment variables.
+     */
+    enum ProxyType {
+        NoProxy,
+        ManualProxy,
+        PACProxy,
+        WPADProxy,
+        EnvVarProxy,
+    };
+
     KProxyDialog(QObject *parent, const KPluginMetaData &data);
     ~KProxyDialog() override;
 
@@ -46,15 +62,21 @@ private Q_SLOTS:
 
 private:
     bool autoDetectSystemProxy(QLineEdit *edit, const QString &envVarStr, bool showValue);
-    QString proxyFor(const QString &protocol) const;
-    QString proxyConfigScript() const;
-    bool useReverseProxy() const;
-    KSaveIOConfig::ProxyType proxyType() const;
+    QString parseProxyString(const QString &protocol) const;
+    ProxyType proxyType() const;
+    void setProxyInformation(const QString &value,
+                             KProxyDialog::ProxyType proxyType,
+                             QLineEdit *manEdit,
+                             QLineEdit *sysEdit,
+                             QSpinBox *spinBox,
+                             const QString &defaultScheme,
+                             KProxyDialog::DisplayUrlFlag flag);
 
     Ui::ProxyDialogUI mUi;
     QStringList mNoProxyForList;
     QMap<QString, QString> mProxyMap;
-    KSharedConfig::Ptr mConfig;
+
+    ProxySettings mSettings;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KProxyDialog::DisplayUrlFlags)
